@@ -439,6 +439,13 @@ Include SCSI storage pools
 
 Include sheepdog storage pools
 
+=item Sys::Virt::StoragePool::LIST_GLUSTER
+
+Include gluster storage pools
+
+=item Sys::Virt::StoragePool::LIST_ZFS
+
+Include ZFS storage pools
 
 =back
 
